@@ -159,10 +159,10 @@ def test_metric_type_name():
         notification_emails=["nobody@example.com"],
         description="description...",
         expires="never",
-        extra_keys={"my_extra": {"description": "an extra"}},
+        extra_keys={"my_extra": {"description": "an extra", "type": "string"}},
     )
 
-    assert kotlin.type_name(event) == "EventMetricType<metricKeys, NoExtras>"
+    assert kotlin.type_name(event) == "EventMetricType<MetricExtra>"
 
     event = metrics.Event(
         type="event",
@@ -174,7 +174,7 @@ def test_metric_type_name():
         expires="never",
     )
 
-    assert kotlin.type_name(event) == "EventMetricType<NoExtraKeys, NoExtras>"
+    assert kotlin.type_name(event) == "EventMetricType<NoExtras>"
 
     boolean = metrics.Boolean(
         type="boolean",
@@ -299,7 +299,7 @@ def test_gecko_datapoints(tmpdir):
             "GV_PAGE_RELOAD_MS" -> PagePerf.reloadTime
             else -> null
         }
-    }"""
+    }"""  # noqa
 
         assert expected_func in content
 
@@ -321,7 +321,7 @@ def test_gecko_datapoints(tmpdir):
             "gfx_adapter.stand_alone" -> GfxInfoAdapter.standAlone
             else -> null
         }
-    }"""
+    }"""  # noqa
 
         assert expected_func in content
 
@@ -331,7 +331,7 @@ def test_gecko_datapoints(tmpdir):
             "gfx_adapter.vendor_id" -> GfxInfoAdapter.vendorId
             else -> null
         }
-    }"""
+    }"""  # noqa
 
         assert expected_func in content
 
@@ -341,7 +341,7 @@ def test_gecko_datapoints(tmpdir):
             "gfx_adapter.width" -> GfxInfoAdapter.screenWidth
             else -> null
         }
-    }"""
+    }"""  # noqa
 
         assert expected_func in content
 
@@ -377,9 +377,11 @@ def test_event_extra_keys_in_correct_order(tmpdir):
     with (tmpdir / "Event.kt").open("r", encoding="utf-8") as fd:
         content = fd.read()
         content = " ".join(content.split())
-        assert "EventExtraKey { alice {" in content
-        assert "bob {" in content
-        assert "charlie {" in content
+        assert "ExampleExtra(" in content
+        assert "alice:" in content
+        assert "bob:" in content
+        assert "charlie:" in content
+        assert ": EventExtras" in content
         assert 'allowedExtraKeys = listOf("alice", "bob", "charlie")' in content
 
 
@@ -406,7 +408,7 @@ def test_arguments_are_generated_in_deterministic_order(tmpdir):
     with (tmpdir / "Event.kt").open("r", encoding="utf-8") as fd:
         content = fd.read()
         content = " ".join(content.split())
-        expected = 'EventMetricType<exampleKeys, NoExtras> by lazy { // generated from event.example EventMetricType<exampleKeys, NoExtras>( CommonMetricData( category = "event", name = "example", sendInPings = listOf("events"), lifetime = Lifetime.PING, disabled = false ), allowedExtraKeys = listOf("alice", "bob", "charlie")) } }'  # noqa
+        expected = 'EventMetricType<ExampleExtra> by lazy { // generated from event.example EventMetricType<ExampleExtra>( CommonMetricData( category = "event", name = "example", sendInPings = listOf("events"), lifetime = Lifetime.PING, disabled = false ), allowedExtraKeys = listOf("alice", "bob", "charlie")) } }'  # noqa
         assert expected in content
 
 
@@ -441,3 +443,37 @@ def test_event_extra_keys_with_types(tmpdir):
         assert (
             'allowedExtraKeys = listOf("enabled", "preference", "swapped")' in content
         )
+
+
+def test_reasons(tmpdir):
+    """
+    Assert that we generate the reason codes as a plain enum.
+
+    https://bugzilla.mozilla.org/show_bug.cgi?id=1811888
+    """
+
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "pings.yaml",
+        "kotlin",
+        tmpdir,
+        {"namespace": "Foo"},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(
+        ["Pings.kt", "GleanBuildInfo.kt"]
+    )
+
+    with (tmpdir / "Pings.kt").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        content = " ".join(content.split())
+
+    expected = '@Suppress("ClassNaming", "EnumNaming") enum class customPingMightBeEmptyReasonCodes : ReasonCode { serious { override fun code(): Int = 0 }, silly { override fun code(): Int = 1 }; }'  # noqa
+    assert expected in content
+
+    expected = "val customPing: PingType<NoReasonCodes> = // generated from custom-ping"
+    assert expected in content
+
+    expected = "val customPingMightBeEmpty: PingType<customPingMightBeEmptyReasonCodes> = // generated from custom-ping-might-be-empty"  # noqa
+    assert expected in content
