@@ -4,6 +4,7 @@
 # http://creativecommons.org/publicdomain/zero/1.0/
 
 from pathlib import Path
+import json
 import re
 import sys
 import textwrap
@@ -143,53 +144,69 @@ def test_parser_schema_violation():
             extra_keys:
                 key_1:
                 description: Sample extra key
+                type: string
                 key_2:
                 description: Sample extra key
+                type: string
                 key_3:
                 description: Sample extra key
+                type: string
                 key_4:
                 description: Sample extra key
+                type: string
                 key_5:
                 description: Sample extra key
+                type: string
                 key_6:
                 description: Sample extra key
+                type: string
                 key_7:
                 description: Sample extra key
+                type: string
                 key_8:
                 description: Sample extra key
+                type: string
                 key_9:
                 description: Sample extra key
+                type: string
                 key_10:
                 description: Sample extra key
+                type: string
                 key_11:
                 description: Sample extra key
+                type: string
                 key_12:
-                  description: Sample extra key
+                description: Sample extra key
+                type: string
                 key_13:
-                  description: Sample extra key
+                description: Sample extra key
+                type: string
                 key_14:
-                  description: Sample extra key
+                description: Sample extra key
+                type: string
                 key_15:
-                  description: Sample extra key
+                description: Sample extra key
+                type: string
                 key_16:
-                  description: Sample extra key
+                description: Sample extra key
+                type: string
         ```
-        {'key_1': {'description': 'Sample extra key'},
-        'key_2': {'description': 'Sample extra key'},
-        'key_3': {'description': 'Sample extra key'},
-        'key_4': {'description': 'Sample extra key'},
-        'key_5': {'description': 'Sample extra key'},
-        'key_6': {'description': 'Sample extra key'},
-        'key_7': {'description': 'Sample extra key'},
-        'key_8': {'description': 'Sample extra key'},
-        'key_9': {'description': 'Sample extra key'},
-        'key_10': {'description': 'Sample extra key'},
-        'key_11': {'description': 'Sample extra key'},
-        'key_12': {'description': 'Sample extra key'},
-        'key_13': {'description': 'Sample extra key'},
-        'key_14': {'description': 'Sample extra key'},
-        'key_15': {'description': 'Sample extra key'},
-        'key_16': {'description': 'Sample extra key'}
+        {'key_1': {'description': 'Sample extra key','type': 'string'},
+        'key_2': {'description': 'Sample extra key','type': 'string'},
+        'key_3': {'description': 'Sample extra key','type': 'string'},
+        'key_4': {'description': 'Sample extra key','type': 'string'},
+        'key_5': {'description': 'Sample extra key','type': 'string'},
+        'key_6': {'description': 'Sample extra key','type': 'string'},
+        'key_7': {'description': 'Sample extra key','type': 'string'},
+        'key_8': {'description': 'Sample extra key','type': 'string'},
+        'key_9': {'description': 'Sample extra key','type': 'string'},
+        'key_10': {'description': 'Sample extra key','type': 'string'},
+        'key_11': {'description': 'Sample extra key','type': 'string'},
+        'key_12': {'description': 'Sample extra key','type': 'string'},
+        'key_13': {'description': 'Sample extra key','type': 'string'},
+        'key_14': {'description': 'Sample extra key','type': 'string'},
+        'key_15': {'description': 'Sample extra key','type': 'string'},
+        'key_16': {'description': 'Sample extra key','type': 'string'}
         } has too many properties
         Documentation for this node:
             The acceptable keys on the "extra" object sent with events. This is an
@@ -323,10 +340,8 @@ def invalid_in_label(name):
 @pytest.mark.parametrize(
     "name",
     [
-        "name/with_slash",
-        "name#with_pound",
-        "this_name_is_too_long_and_shouldnt_be_used",
-        "",
+        "1" * 72,
+        "Møøse",
     ],
 )
 def test_invalid_names(location, name):
@@ -737,10 +752,20 @@ def test_historical_versions():
     Make sure we can load the correct version of the schema and it will
     correctly reject or not reject entries based on that.
     """
+
+    # No issues:
+    # * Bugs as numbers
+    # * event extra keys don't have a type
     contents = [
         {
             "$schema": "moz://mozilla.org/schemas/glean/metrics/1-0-0",
-            "category": {"metric": {"type": "event", "bugs": [42]}},
+            "category": {
+                "metric": {
+                    "type": "event",
+                    "extra_keys": {"key_a": {"description": "foo"}},
+                    "bugs": [42],
+                }
+            },
         }
     ]
     contents = [util.add_required(x) for x in contents]
@@ -750,10 +775,20 @@ def test_historical_versions():
     errors = list(all_metrics)
     assert len(errors) == 0
 
+    # 1 issue:
+    # * Bugs as numbers are disallowed
+    #
+    # events: not having a `type` is fine in version 2.
     contents = [
         {
             "$schema": "moz://mozilla.org/schemas/glean/metrics/2-0-0",
-            "category": {"metric": {"type": "event", "bugs": [42]}},
+            "category": {
+                "metric": {
+                    "type": "event",
+                    "extra_keys": {"key_a": {"description": "foo"}},
+                    "bugs": [42],
+                }
+            },
         }
     ]
     contents = [util.add_required(x) for x in contents]
@@ -809,6 +844,51 @@ def test_rates():
     )  # Hasn't been transformed to "denominator" yet
 
 
+def test_ping_ordering():
+    contents = parser.parse_objects(
+        [ROOT / "data" / "pings.yaml"],
+        config={"allow_reserved": False},
+    )
+
+    errs = list(contents)
+    assert len(errs) == 0
+
+    pings = list(contents.value["pings"].keys())
+
+    assert pings == sorted(pings)
+
+
+def test_metric_ordering():
+    all_metrics = parser.parse_objects(
+        [ROOT / "data" / "ordering.yaml"], config={"allow_reserved": False}
+    )
+
+    errs = list(all_metrics)
+    assert len(errs) == 0
+
+    category = all_metrics.value["testing.ordering"]
+
+    assert len(category.values()) > 0
+    test_metrics = [f"{m.category}.{m.name}" for m in category.values()]
+
+    # Alphabetically ordered
+    assert test_metrics == [
+        "testing.ordering.a_second_test_metric",
+        "testing.ordering.first_test_metric",
+        "testing.ordering.third_test_metric",
+    ]
+
+
+def test_tag_ordering():
+    all_metrics = parser.parse_objects(ROOT / "data" / "metric-with-tags.yaml")
+
+    errs = list(all_metrics)
+    assert len(errs) == 0
+
+    tags = all_metrics.value["telemetry"]["client_id"].metadata["tags"]
+    assert tags == sorted(tags)
+
+
 def test_text_valid():
     """
     Ensure that `text` metrics parse properly.
@@ -901,3 +981,66 @@ def test_no_lint_sorted():
     assert all_objects.value["category"]["metric"].no_lint == ["lint1", "lint2"]
     assert all_objects.value["pings"]["ping"].no_lint == ["lint1", "lint2"]
     assert all_objects.value["tags"]["tag"].no_lint == ["lint1", "lint2"]
+
+
+def test_no_internal_fields_exposed():
+    """
+    We accidentally exposed fields like `_config` and `_generate_enums` before.
+    These ended up in probe-scraper output.
+
+    We replicate the code probe-scraper uses
+    and ensure we get the JSON we expect from it.
+    """
+
+    results = parser.parse_objects(
+        [
+            util.add_required(
+                {
+                    "category": {
+                        "metric": {
+                            "type": "event",
+                            "extra_keys": {
+                                "key_a": {"description": "desc-a", "type": "boolean"}
+                            },
+                        }
+                    },
+                }
+            ),
+        ]
+    )
+    errs = list(results)
+    assert len(errs) == 0
+
+    metrics = {
+        metric.identifier(): metric.serialize()
+        for category, probes in results.value.items()
+        for probe_name, metric in probes.items()
+    }
+
+    expected = {
+        "category.metric": {
+            "bugs": ["http://bugzilla.mozilla.org/12345678"],
+            "data_reviews": ["https://example.com/review/"],
+            "defined_in": {"line": 3},
+            "description": "DESCRIPTION...",
+            "disabled": False,
+            "expires": "never",
+            "extra_keys": {"key_a": {"description": "desc-a", "type": "boolean"}},
+            "gecko_datapoint": "",
+            "lifetime": "ping",
+            "metadata": {},
+            "no_lint": [],
+            "notification_emails": ["nobody@example.com"],
+            "send_in_pings": ["events"],
+            "type": "event",
+            "version": 0,
+        }
+    }
+    expected_json = json.dumps(expected, sort_keys=True, indent=2)
+
+    out_json = json.dumps(
+        metrics,
+        sort_keys=True,
+        indent=2,
+    )
+    assert expected_json == out_json
