@@ -25,6 +25,21 @@ def test_translate_unknown_format():
     assert "Unknown output format" in str(e)
 
 
+def test_all_metrics(tmpdir):
+    output = Path(str(tmpdir)) / "tags_test"
+
+    translate.translate(
+        [ROOT / "data" / "all_metrics.yaml"],
+        "kotlin",
+        output,
+        options={"with_buildinfo": "false"},
+        parser_config={"allow_reserved": True},
+    )
+
+    # A single metric category in a single file
+    assert len(list(output.iterdir())) == 1
+
+
 def test_translate_missing_directory(tmpdir):
     output = Path(str(tmpdir)) / "foo"
 
@@ -189,17 +204,11 @@ def test_getting_line_number():
     metrics = load_yaml_or_json(ROOT / "data" / "core.yaml")
 
     assert pings["custom-ping"].defined_in["line"] == 7
-    assert metrics["core_ping"]["seq"].defined_in["line"] == 67
+    assert metrics["core_ping"]["seq"].defined_in["line"] == 69
 
 
 def test_rates(tmpdir):
     def external_translator(all_objects, output_dir, options):
-        assert (
-            all_objects["testing.rates"]["has_external_denominator"].type == "rate"
-        )  # Hasn't yet been transformed
-
-        translate.transform_metrics(all_objects)
-
         category = all_objects["testing.rates"]
         assert category["has_internal_denominator"].type == "rate"
         assert category["has_external_denominator"].type == "numerator"
@@ -213,10 +222,17 @@ def test_rates(tmpdir):
             == "testing.rates.the_denominator"
         )
         assert category["the_denominator"].type == "denominator"
-        assert category["the_denominator"].numerators == [
-            "testing.rates.has_external_denominator",
-            "testing.rates.also_has_external_denominator",
+
+        numerators = [
+            f"{m.category}.{m.name}" for m in category["the_denominator"].numerators
         ]
+        # Because generation gaurantees order, this must be sorted.
+        assert numerators == sorted(
+            [
+                "testing.rates.has_external_denominator",
+                "testing.rates.also_has_external_denominator",
+            ]
+        )
 
     translate.translate_metrics(
         ROOT / "data" / "rate.yaml",
